//***********************************************************************************//
//*	Project:	PSoC4 BLE Access to the FRam										*//
//*																					*//
//*	File:		FRam.c			 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2015	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*																					*//
//*		Simply accessing the FM2010 on the Pioneer BLE board using 					*//
//*		the I2C interface															*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <FRam.h>

//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//******************* Data Area *****************************************************//
//***********************************************************************************//
static uint16 LowerAddress;
static uint8 I2CAddress;

//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//
static uint32 SetFramAddress(void *FRamAddress);

//***********************************************************************************//
//****************** Program Area ***************************************************//
//***********************************************************************************//
void FRam_Start(void)														//	Start all needed components
{
	FRamInterface_Start();
}
//**********************************************************************

uint32 FRam_Write(void * Data, void * FRamAddress, uint16 Count)			//	Write to FRam
{
uint32	Result;
uint16	ii = 0;
	
	if((Result = SetFramAddress(FRamAddress))) 
		return Result;
	
	while(ii++ < Count)
	{
		Result = FRamInterface_I2CMasterWriteByte(*(uint8 *)(Data++));
		if(Result) return Result;
	}
	Result = FRamInterface_I2CMasterSendStop();
	return Result;
}
//**********************************************************************

uint32 FRam_Read (void * Destination, void * FRamAddress, uint16 Count)	//	Read from FRam
{
uint32	Result;
uint16	ii = 0;
	
	if((Result = SetFramAddress(FRamAddress))) return Result;
	
	Result = FRamInterface_I2CMasterSendRestart(I2CAddress,FRamInterface_I2C_READ_XFER_MODE);
	if(Result) return Result;

	while(ii++ < Count)
	{
		*(uint8*)(Destination++) = FRamInterface_I2CMasterReadByte(ii < (Count)?FRamInterface_I2C_ACK_DATA:FRamInterface_I2C_NAK_DATA);
	}
	Result = FRamInterface_I2CMasterSendStop();
	return Result;
}
//**********************************************************************

void FRam_Stop(void)														//	Stop all used components
{
	FRamInterface_Stop();
}
//**********************************************************************

static uint32 SetFramAddress(void *FRamAddress)								
{
uint32 Result;	
	I2CAddress = FRamI2CAddress;
	if((uint32)FRamAddress & 0x1ul << 16) I2CAddress |= 0x01;				//	Isolate Address-bit 16
	LowerAddress = LO16((uint16)((uint32)FRamAddress));						//	and insert it into slave address

	Result = FRamInterface_I2CMasterSendStart(I2CAddress,FRamInterface_I2C_WRITE_XFER_MODE);
	if(Result) return Result;
	Result = FRamInterface_I2CMasterWriteByte((uint32)((LowerAddress >> 8) & 0x000000ff));
	if(Result) return Result;
	Result = FRamInterface_I2CMasterWriteByte((uint32)(LowerAddress &  0x000000ff));
	return Result;
}
//**********************************************************************


