//***********************************************************************************//
//*	Project:	PSoC4 BLE Access to the FRam										*//
//*																					*//
//*	File:		FRam.h			 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2015	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*		Simply accessing the FM2010 on the Pioneer BLE board using 					*//
//*		the I2C interface															*//
//*																					*//
//***********************************************************************************//
#ifndef FRam_h
#define FRam_h
	
//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <project.h>
#include <main.h>
//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//
#define	FRamI2CAddress	0x50

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//
//	None yet


//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//	

//***********************************************************************************//
void	FRam_Start(void);													//	Start all needed components
//*																					*//
//*		Starts the I2C component and the I2C Clock									*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
uint32	FRam_Write(void * Data, void * FRamAddress, uint16 Count);			//	Write to FRam
//*																					*//
//*		Write data into FRam														*//
//*																					*//
//*		Data:		Pointer to the data to be written (Source)						*//
//*		FRamAddress:Pointer to FRam location where data is stored (Destination)		*//
//*		Count:		Number of bytes to transfer from Source to destination			*//
//*																					*//
//*		Returns:	Number of free bytes in FRam									*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
uint32	FRam_Read (void * Destination, void * FRamAddress, uint16 Count);	//	Read from FRam
//*																					*//
//*		Read data from FRam															*//
//*																					*//
//*		Destination:Pointer to the buffer to store the data							*//
//*		FRamAddress:Pointer to FRam location where data is red from (Source)		*//
//*		Count:		Number of bytes to transfer from Source to destination			*//
//*																					*//
//*		Returns:	Number of free bytes in FRam									*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
void	FRam_Stop(void);													//	Stop all used components
//*																					*//
//*		Halt the I2C interface and the I2C Clock component							*//
//*																					*//
//***********************************************************************************//
		
	
#endif

/* [] END OF FILE */
