//***********************************************************************************//
//*	Project:	PSoC4 Maintaining a real-time clock (RTC)							*//
//*																					*//
//*	File:		TimeKeeper.h	 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2014	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*																					*//
//*		The Tick timer of the ARM CPU is used to maintain a real-time-clock			*//
//*		with an accuracy of 1 second. The precision depends on the oscillator		*//
//*		precision of the PSoC.														*//
//*																					*//
//***********************************************************************************//
#ifndef TimeKeeper_h
#define TimeKeeper_h
	
//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <cytypes.h>

//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//	
	
	
struct TimeDate												//	Time and date structure
		{
		uint16	Year;
		uint16	DayOfYear;									//	Day in the year 1..365/366
		uint8	Hour;
		uint8	Minute;
		uint8	Second;
		};
typedef struct TimeDate * TimeDate;							//	Pointer type to the TimeDate structure


struct Calendar
		{
		uint16	Year;
		uint8	Month;
		uint8	DayInMonth;
		uint8	WeekDay;									//	0..6, Sunday..Saturday
		};
typedef struct Calendar * Calendar;		
		
extern struct TimeDate ActualTimeDate;						//	Allows access to time and date	
		
//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//		
TimeDate TimeKeeper_Start(void);							//	Start the TimeKeeper, return address of TimerDate structure
void	TimeKeeper_Stop();									//	Stops all Timekeeper actions
void	TimeKeeper_SetTimeAndDate(TimeDate NewTimeDate);	//	Set current time and date
void	TimeKeeper_GetTimeAndDate(TimeDate ActTime);		//	Get Time and date;
void	TimeKeeper_Halt(void);								//	Halts the TimeKeeper
void	TimeKeeper_Run(void);								//	Resume halted TimeKeeper
Calendar TimeKeeper_CalcDate(void);							//	Calculate Month, weekday etc from TimeDate

#endif
	