//***********************************************************************************//
//*	Project:	Data Logger using F-Ram												*//
//*				Underlying Hardware: Pioneer BLE Kit								*//
//*																					*//
//*	File:		main.c			 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2015	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*		Accessing the FM2010 on the Pioneer BLE board using 						*//
//*		the I2C interface															*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <project.h>
#include <main.h>
#include <DataLogger.h>
#include <TimeKeeper.h>

//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//******************* Data Area *****************************************************//
//***********************************************************************************//

//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//
void BlinkLEDs(uint8 Number);
void GenerateLogEntries(uint8 Number, uint16 DelayBetween);
void ConsumeLogEntries(void);

//***********************************************************************************//
//**************** Program Area *****************************************************//
//***********************************************************************************//

void InitializeHardware(void)
{
	CyGlobalIntEnable;
	DataLogger_Start();
}
//***********************************************************************************//

int main()
{
	InitializeHardware();
	BlinkLEDs(1);										//	Signal program start
	while(forever)
    {
		GenerateLogEntries(30,5);
		ConsumeLogEntries();
	}
}
//***********************************************************************************//

void BlinkLEDs(uint8 Number)							//	turn on and off RGB-LEDs
{
#define DELAY (500)
	while(Number--)
	{
		LED_Red_Write(LEDON);
		CyDelay(DELAY);
		LED_Red_Write(LEDOFF);
		LED_Green_Write(LEDON);
		CyDelay(DELAY);
		LED_Green_Write(LEDOFF);
		LED_Blue_Write(LEDON);
		CyDelay(DELAY);
		LED_Blue_Write(LEDOFF);
	}
#undef DELAY
}
//***********************************************************************************//

void GenerateLogEntries(uint8 Number, uint16 DelayBetween)
{
uint32 MyData = 0xFFEEDD00u;	
uint8 ii = 0;
uint16 IsFree;
	while(ii++ < Number)
	{
		IsFree = DataLogger_LogEntry(ii,&MyData,sizeof(MyData));
		MyData++;
		CyDelay(DelayBetween);
	}
}
//***********************************************************************************//

void ConsumeLogEntries(void)		
{
void * MyEntry;
uint16 EntrySize;
uint16 EntryType;
uint16 EntryCount;
	while((EntryCount = DataLogger_GetEntryCount()))
	{
		EntrySize	= DataLogger_GetActualEntrySize();
		EntryType	= DataLogger_GetActualEntryType();
		MyEntry		= DataLogger_GetLogEntry(&EntryType,&EntrySize);
		
		DataLogger_FreeLogEntry(MyEntry);
	}
}
//***********************************************************************************//

/* [] END OF FILE */
